//
// Created by Matthew on 2023/12/27.
//

#ifndef MICROPHOTO_GPIOCONTROL_H
#define MICROPHOTO_GPIOCONTROL_H

#include <string>

#define CMD_GET_LIGHT_ADC                       101
#define CMD_SET_LIGHT_ADC                       102
#define CMD_GET_KEY_LOCKSTATE                   103
#define CMD_GET_BAT_ADC                         104
#define CMD_SET_FLASH_LED                       105
#define CMD_SET_NETWORK_STATE                   106
#define CMD_SET_OTG_STATE                       107
#define CMD_GET_OTG_STATE                       108
#define CMD_GET_CHARGING_VOL_STATE              110
#define CMD_GET_CHARGING_SHUNT_VOLTAGE_STATE    111
#define CMD_GET_CHARGING_BUS_VOLTAGE_STATE      112
#define CMD_GET_CHARGING_POWER_STATE            113
#define CMD_GET_CHARGING_CURRENT_STATE          114
#define CMD_GET_BAT_VOL_STATE                   115
#define CMD_GET_BAT_SHUNT_VOLTAGE_STATE         116
#define CMD_GET_BAT_BUS_VOLTAGE_STATE           117
#define CMD_GET_BAT_POWER_STATE                 118
#define CMD_GET_BAT_CURRENT_STATE               119
#define CMD_SET_485_STATE                       121
#define CMD_SET_SPI_MODE                        123
#define CMD_SET_SPI_BITS_PER_WORD               124
#define CMD_SET_SPI_MAXSPEEDHZ                  125
#define CMD_SET_PWM_BEE_STATE                   126
#define CMD_SET_ALM_MODE                        128
#define CMD_SET_SPI_POWER                       129
#define CMD_SET_485_EN_STATE					131
#define CMD_SET_CAM_3V3_EN_STATE				132
#define CMD_SET_12V_EN_STATE					133
#define CMD_SET_SYSTEM_RESET  		            202
#define CMD_SET_WTH_POWER							490
#define CMD_SET_PULL_POWER							491
#define CMD_SET_ANGLE_POWER							492
#define CMD_SET_OTHER_POWER							493
#define CMD_SET_PIC1_POWER							494
#define CMD_SET_485_en0							301
#define CMD_SET_485_en1							302
#define CMD_SET_485_en2							303
#define CMD_SET_485_en3							304
#define CMD_SET_485_en4							305

#define CMD_SET_ADC_ENABLE							500
#define CMD_SET_MIPI_SWITCH							501
#define CMD_SET_CAM_RSTN1							502
#define CMD_SET_CAM_RSTN0							503
#define CMD_SET_SENSOR_ENABLE						504
#define CMD_SET_SENSOR_PWR_ENABLE					505
#define CMD_SET_SENSOR2_ENABLE						506
#define CMD_SET_SD_DECT								507
#define CMD_SET_PTZ_PWR_ENABLE						508
#define CMD_SET_SENSOR3_PWR_ENABLE					509
#define CMD_SET_SENSOR4_ENABLE						510
#define CMD_SET_RTC_ENABLE							511
#define CMD_SET_485_ENABLE							512
#define CMD_SET_SENSOR1_PWR_ENABLE					513
#define CMD_SET_SENSOR2_PWR_ENABLE					514
#define CMD_SET_PHOTO_OUT							515
#define CMD_SET_3V3_PWR_ENABLE						516
#define CMD_SET_5V_PWR_ENABLE						517
#define CMD_SET_100M_ENABLE							518
#define CMD_SET_100M_SWITCH_PWR_ENABLE				519
#define CMD_SET_PHOTO_IN							520
#define CMD_SET_AM_POWER_ENABLE						521
#define CMD_SET_NRSEC_POWER_ENABLE					522
#define CMD_SET_AMP_ENABLE							523
#define CMD_SET_LIGHT1_RESISTOR_ENABLE				524
#define CMD_SET_SENSOR4_PWR_ENABLE					525
#define CMD_SET_100M_RESET							526

class GpioControl
{
public:

    static void setInt(int cmd, int value);
    static int getInt(int cmd);
    static void setLong(int cmd, long value);
    static long getLong(int cmd);
    static void setString(int cmd, const std::string& value);
    static std::string getString(int cmd);

    static void setOtgState(bool on)
    {
        setInt(CMD_SET_OTG_STATE, on ? 1 : 0);
    }

    static bool getOtgState()
    {
        return getInt(CMD_SET_OTG_STATE) != 0;
    }

    static void setCam3V3Enable(bool enabled)
    {
        setInt(CMD_SET_CAM_3V3_EN_STATE, enabled ? 1 : 0);
    }

    static void reboot()
    {
        setInt(CMD_SET_SYSTEM_RESET, 1);
    }

    static void setLightAdc(int i)
    {
        setInt(CMD_SET_LIGHT_ADC, i);
    }

    static int getLightAdc()
    {
        return getInt(CMD_GET_LIGHT_ADC);
    }

    static int getChargingVoltage()
    {
        return getInt(CMD_GET_CHARGING_VOL_STATE);
    }

    static int getChargingShuntVoltage()
    {
        return getInt(CMD_GET_CHARGING_SHUNT_VOLTAGE_STATE);
    }

    static int getChargingBusVoltage() {
        return getInt(CMD_GET_CHARGING_BUS_VOLTAGE_STATE);
    }

    static int getChargingPower() {
        return getInt(CMD_GET_CHARGING_POWER_STATE);
    }

    static int getChargingCurrent() {
        return getInt(CMD_GET_CHARGING_CURRENT_STATE);
    }

    static int getBatteryVoltage() {
        return getInt(CMD_GET_BAT_VOL_STATE);
    }

    static int getBatteryShuntVoltage() {
        return getInt(CMD_GET_BAT_SHUNT_VOLTAGE_STATE);
    }

    static int getBatteryBusVoltage() {
        return getInt(CMD_GET_BAT_BUS_VOLTAGE_STATE);
    }

    static int getBatteryPower() {
        return getInt(CMD_GET_BAT_POWER_STATE);
    }

    static int getBatteryCurrent() {
        return getInt(CMD_GET_BAT_CURRENT_STATE);
    }

    static void set485WriteMode() {
        setInt(CMD_SET_485_STATE, 1);
    }

    static void set485ReadMode() {
        setInt(CMD_SET_485_STATE, 0);
    }

    static void setSpiMode(int i) {
        setInt(CMD_SET_SPI_MODE, i);
    }

    static void setSpiBitsPerWord(int i) {
        setInt(CMD_SET_SPI_BITS_PER_WORD, i);
    }

    static void setSpiMaxSpeedHz(long j) {
        setLong(CMD_SET_SPI_MAXSPEEDHZ, j);
    }

    static void setBeeOn(bool z) {
        setInt(CMD_SET_PWM_BEE_STATE, z ? 1 : 0);
    }

    static void setJidianqiState(bool z) {
        setInt(CMD_SET_ALM_MODE, z ? 1 : 0);
    }

    static void setSpiPower(bool on) {
        setInt(CMD_SET_SPI_POWER, on ? 1 : 0);
    }

    static void setRS485Enable(bool z) {
        setInt(CMD_SET_485_EN_STATE, z ? 1 : 0);
    }


    static void set12VEnable(bool z) {
        setInt(CMD_SET_12V_EN_STATE, z ? 1 : 0);
    }

};


#endif //MICROPHOTO_GPIOCONTROL_H
